@@ -1,6 +1,6 @@
 /**
  * @file     element.h
- * @brief    Element's handling routines
+ * @brief    SCEW element's handling routines
  * @author   Aleix Conchillo Flaque <aleix@member.fsf.org>
  * @date     Mon Nov 25, 2002 00:48
  * @ingroup  SCEWElement, SCEWElementAcc, SCEWElementAttr, SCEWElementHier
@@ -62,6 +62,20 @@ typedef struct scew_element scew_element;
  */
 typedef struct scew_attribute scew_attribute;
 
+/**
+ * SCEW element compare hooks might be used to define new user XML
+ * element comparisons. This hook must only compare the element's name
+ * and contents and the list of attributes. The new hook is to be used
+ * by #scew_element_compare.
+ *
+ * @return true if the given elements are considered equal, false
+ * otherwise.
+ *
+ * @ingroup SCEWElementCompare
+ */
+typedef scew_bool (*scew_element_cmp_hook) (scew_element const *,
+                                            scew_element const *);
+
 
 /**
  * @defgroup SCEWElementAlloc Allocation
@@ -166,21 +180,39 @@ scew_element_list_by_name (scew_element const *element, XML_Char const *name);
  */
 
 /**
- * Performs a deep comparison of the two given elements. That is, it
- * compares that both elements have the same name, attributes,
- * contents, children (recursively), etc.
+ * Performs a deep comparison of the two given elements. The
+ * comparison is done via the comparison @a hook. If @a hook is NULL,
+ * the default comparison is done:
  *
- * Remember that XML is case-sensitive.
+ * - Name and contents are equal (case-sensitive).
+ * - Number of attributes match.
+ * - Attribute names and values match (case-sensitive).
+ *
+ * It is important to note that, for any given hook (or if NULL), the
+ * children are automatically traversed recursively using the given @a
+ * hook. Therefore, the hook must only provide comparisons for
+ * element's name and contents and the list of attribtues.
+ *
+ * There is no restriction on the provided comparison hook (if any),
+ * thus the user is responsible to define how the comparison is to be
+ * done.
  *
  * @pre a != NULL
  * @pre b != NULL
  *
- * @return true if both elements are equal, false otherwise.
+ * @param a one of the elements to compare.
+ * @param b one of the elements to compare.
+ * @param hook the user defined comparison function. If NULL, the
+ * default comparison is used.
+ *
+ * @return true if both elements are considered equal, false
+ * otherwise.
  *
  * @ingroup SCEWElementCompare
  */
 extern SCEW_API scew_bool scew_element_compare (scew_element const *a,
-                                                scew_element const *b);
+                                                scew_element const *b,
+                                                scew_element_cmp_hook hook);
 
 
 /**
